/**
 * 
 * 17. Blog styling
 * 
 */


/** 17.01 Base blog styles **/
.hentry {
	margin: 0 0 5em 0;
}

.entry-content,
.entry-summary {
	word-wrap: break-word;

	p {
		font-size: 1.16em;
		line-height: 1.55em;
	}

	ul {
		font-size: 14px;
		line-height: 1.55em;
	}

	td, th {
		vertical-align: middle;
	}
}


/** 17.02 Blog posts **/
article {
	&.row {
		margin: 0 0 5em 0;

		.entry-summary:first-child {
			margin-top: 2em; //in article list with no title
		}
		
		@include at-least($bp-xxs) {
			background-color: #fff;	
		}
	}
	
	/* 17.02.1 Article thumbnail */
	.entry-thumbnail {
		a {
			display: block;
			width: 100%;
			max-width: 100%; /* ff fix */
			text-align: center;

			&.entry-thumb-cover {
				min-height: 350px;
				background-repeat: no-repeat;
				background-size: cover;
				background-position: center center;

				&.lazyload-bg,
				&.lazyloading-bg {
					opacity: 0; 
				}
			}

			&:hover {
				opacity: 0.85;
			}
		}
	}

	/* 17.02.2 Article headings */
	.content-header {
		border-bottom: 0;
		padding-bottom: 0;
		margin: 0 auto 10px auto;
		-ms-word-wrap: break-word;
		word-wrap: break-word;
		
		.page-title a {
			color: $color-darker-gray;
			font-size: 20px;
			@extend %uppercase;
		}
		.section-title span {
			border-color: #1A1A1A;
		}
	}

	/* 17.02.3 Article meta */
	.entry-meta {
		font-size: 13px;
		margin-bottom: 10px;
		color: $color-dark-gray;

		a {
			color: $color-darker-gray;

			&:hover {
				color: $color-primary; /* redux[color: main_theme_color] */
			}
		}
	}

	/* 17.02.4 Article content */
	.entry-content {
		position:relative;
		padding-bottom: 1.5em;
		margin-bottom: 1.5em;

		.more-link {
			display: none; //permalink in entry-footer
		}

		.page-links {
			@extend %text-theme;
			margin-top: 1em;
		}
	}

	&.post .entry-content:after {
		content: '';
		display: block;
		position: absolute;
		bottom: 0;
		left: 0;
		width: 40px; height: 2px;
		background-color: $color-dark-gray;		
	}

	/* 17.02.5 Article edit & more links */
	.more-link, .post-edit-link {
		@extend %text-theme;
		@extend %simple-transition;
		border: none;
		padding: 0 10px;
		font-size: 13px;
		border-radius: 2px;
		display: inline-block;

		&:last-child {
			margin-right: 0;
			padding-right: 0;
		}

		&:after {
			@extend %ion;
			margin-left: 5px;
			font-size: 1em;
			@include transition(margin $duration ease-in-out);
		}

		&:hover {
			&:after {
				margin-left: 10px;	
			}
		}
	}

	.more-link:after {
		content: $ionicon-var-arrow-right-b;
	}

	.post-edit-link:after {
		content: $ionicon-var-android-create;
	}

	/* 17.02.6 Sticky post extra styling */
	&.sticky {
		background: rgba(255, 255, 255, 0.8);
		box-shadow: 0 0 10px 0px rgba(0, 0, 0, 0.15);
		border-bottom: 3px solid #ed6736;

		@include until($bp-xxs) {
			.article-content {
				padding-left: 10px;
				padding-right: 10px;		
			}
		}
	}

	footer.entry-meta {
		overflow: hidden;
	}

	+ #nav-below {
		display: none;
	}
}

.single-post article.post {
	background-color: transparent;
}


.article-content {
	footer {
		text-align: right;
		margin: 20px 0;
	}

	@include until($bp-xxs) {
		padding-left: 0;
		padding-right: 0;
	}	
}

// in article Images
.wp-caption {
	margin-bottom: 10px;
	max-width: 100%;
	width: 100%;
	background-color: rgba(144, 144, 144, 0.05);
	border: 1px solid rgba(144, 144, 144, 0.1);
	padding: 0;

	&.aligncenter {
		margin-bottom: 10px;
	}
	img {
		margin: 0;
	}
	img[class*="wp-image-"] {
		display: block;
	}
	.wp-caption-text {
		margin: 6px 0;
		padding-left: 8px;
		padding-right: 8px;
	}
}


/** 17.03 Attachment posts **/
article.attachment {
	position: relative;

	.entry-content {
		text-align: center;
		padding-left: 60px;
		padding-right: 60px;
	}

	.image-navigation {
		.nav-previous,
		.nav-next {
			position: absolute;
			top: 50%;
			margin-top: -60px;
			left: 0;

			i {
				font-size: 50px;
				line-height: 50px;
				width: 50px;
				@include transition(color $duration-color $fn-cubic);
			}
		}

		.nav-next {
			left: auto;
			right: 0;
		}

		a:hover {
			i {
				color: $color-primary; /* redux[color: main_theme_color] */
			}
		}
	}

	footer.entry-meta {
		font-weight: 700;
		padding: 0 60px;
		text-align: center;

		a {
			font-weight: 700;
		}
	}
}


/** 17.04 Posts navigation **/
.main-content-bottom-holder {
 	@extend %uppercase;
	background-color: #fff;
	padding: 0;
	overflow: hidden;
	
	a {
		color: $color-dark-gray;

		&:visited {
			color: $color-dark-gray;
		}
		&:hover {
			color: $color-primary; /* redux[color: main_theme_color] */
		}

		span {
			@include transition(transform 0.2s ease-in-out);
		}
	}

	nav {
		margin-top: 20px;
		margin-bottom: 20px;

		.nav-previous {
			float: left;
			text-align: left;
			width: 48%;

			a > * {
				float: left;
				text-align: left;
			}

			a:hover span {
				@include transform(translateX(-5px));
			}
		}
		
		.nav-next {
			float: right;
			text-align: right;
			width: 48%;

			a > * {
				float: right;
				text-align: right;
			}

			a:hover span {
				@include transform(translateX(5px));
			}
		}

		i {
			font-size: 50px;
			line-height: 50px;
			height: 50px;
			width: 30px;
		}
		span {
			line-height: 50px;
			font-size: 14px;
			font-weight: 700;
			margin: 2px 10px 0 10px;
			opacity: 1;
			width: 80%;
			white-space: nowrap;
			overflow: hidden;
			text-overflow: ellipsis;
		}
	}
}

@media (max-width: 768px) {
	.main-content-bottom-holder nav span {
		display: none;
	}
}